@@ -6,12 +6,11 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cfloat>
-
 #include "DgDVec3D.h"
+#include <limits>
 
 ////////////////////////////////////////////////////////////////////////////////
 
-const DgDVec3D& DgDVec3D::undefDgDVec3D = DgDVec3D(DBL_MAX, DBL_MAX, DBL_MAX);
+const DgDVec3D& DgDVec3D::undefDgDVec3D = DgDVec3D(std::numeric_limits<double>::max(), std::numeric_limits<double>::max(), std::numeric_limits<double>::max());
 
 ////////////////////////////////////////////////////////////////////////////////
